Package: terraTCGAdata
Type: Package
Title: OpenAccess TCGA Data on Terra as MultiAssayExperiment
Version: 1.17.1
Authors@R: c(
    person("Marcel", "Ramos", , "marcel.ramos@sph.cuny.edu", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-3242-0582")),
    person("NHGRI", role = "fnd",
           comment = c(GrantNo. = "U24HG010263"))
  )
Description: Leverage the existing open access TCGA data on Terra with
    well-established Bioconductor infrastructure. Make use of the Terra
    data model without learning its complexities. With a few functions,
    you can copy / download and generate a MultiAssayExperiment from the
    TCGA example workspaces provided by Terra.
Depends: AnVILGCP, MultiAssayExperiment
biocViews: Software, Infrastructure, DataImport
Imports: AnVIL, BiocFileCache, dplyr, GenomicRanges, methods,
        RaggedExperiment, readr, S4Vectors, stats, tidyr, TCGAutils,
        utils
Suggests: AnVILBase, GCPtools, knitr, rmarkdown, BiocStyle, withr,
        testthat (>= 3.0.0)
URL: https://github.com/waldronlab/terraTCGAdata
BugReports: https://github.com/waldronlab/terraTCGAdata/issues
VignetteBuilder: knitr
License: Artistic-2.0
Encoding: UTF-8
RoxygenNote: 7.3.3
Config/testthat/edition: 3
Date: 2025-11-17
git_url: https://git.bioconductor.org/packages/terraTCGAdata
git_branch: devel
git_last_commit: ffca88e
git_last_commit_date: 2026-04-29
Repository: Bioconductor 3.24
Date/Publication: 2026-05-18
NeedsCompilation: no
Packaged: 2026-05-18 23:39:43 UTC; biocbuild
Author: Marcel Ramos [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-3242-0582>),
  NHGRI [fnd] (GrantNo.: U24HG010263)
Maintainer: Marcel Ramos <marcel.ramos@sph.cuny.edu>
Built: R 4.6.0; ; 2026-05-19 05:12:09 UTC; unix
