# Generated by roxygen2: do not edit by hand

export(getAssayData)
export(getAssayTable)
export(getClinical)
export(getClinicalTable)
export(getTCGAdatalist)
export(sampleTypesTable)
export(selectTCGAworkspace)
export(terraTCGAdata)
export(terraTCGAworkspace)
import(AnVIL)
import(MultiAssayExperiment)
importFrom(AnVILGCP,avcopy)
importFrom(AnVILGCP,avtable)
importFrom(AnVILGCP,avworkspaces)
